Module convert

Module convert 

Bidirectional conversion between Polars DataFrames and domain types (Tick, Bar).

Functions

bars_to_dataframe
Convert a slice of Bars into a Polars DataFrame.
dataframe_to_bars
Convert a Polars DataFrame back into Vec.
dataframe_to_ticks
Convert a Polars DataFrame back into Vec.
ndt_to_date_string
Extract the date portion from a NaiveDateTime as a formatted string.
ticks_to_dataframe
Convert a slice of Ticks into a Polars DataFrame.