pub struct ParquetBarScan { /* private fields */ }Expand description
An immutable description of bounded bar partitions.
Implementations
Sourceimpl ParquetBarScan
impl ParquetBarScan
Sourcepub fn describe(
root: impl AsRef<Path>,
exchange: &str,
symbol: &str,
timeframe: &str,
bounds: ParquetScanBounds,
) -> Result<Self>
pub fn describe( root: impl AsRef<Path>, exchange: &str, symbol: &str, timeframe: &str, bounds: ParquetScanBounds, ) -> Result<Self>
Describe bar partitions and bind each path to its current file fingerprint.
Sourcepub fn describe_cancellable<F>(
root: impl AsRef<Path>,
exchange: &str,
symbol: &str,
timeframe: &str,
bounds: ParquetScanBounds,
is_cancelled: F,
) -> Result<Self>
pub fn describe_cancellable<F>( root: impl AsRef<Path>, exchange: &str, symbol: &str, timeframe: &str, bounds: ParquetScanBounds, is_cancelled: F, ) -> Result<Self>
Describe bar partitions with cooperative cancellation.
Sourcepub fn cursor(&self) -> Result<ParquetBarCursor>
pub fn cursor(&self) -> Result<ParquetBarCursor>
Open a cursor against the file generations bound by this description.
Sourcepub fn cursor_with_read_size(
&self,
rows_per_read: usize,
) -> Result<ParquetBarCursor>
pub fn cursor_with_read_size( &self, rows_per_read: usize, ) -> Result<ParquetBarCursor>
Open a cursor with a maximum number of rows decoded per read.
Sourcepub fn latest_valid_bar_cancellable<F>(
&self,
is_cancelled: F,
) -> Result<Option<ParquetScannedRow<Bar>>>
pub fn latest_valid_bar_cancellable<F>( &self, is_cancelled: F, ) -> Result<Option<ParquetScannedRow<Bar>>>
Find the latest bar with a valid close inside the inclusive scan bounds.