pub struct ParquetTickScan { /* private fields */ }Expand description
An immutable description of bounded tick partitions.
Implementations
Sourceimpl ParquetTickScan
impl ParquetTickScan
Sourcepub fn describe(
root: impl AsRef<Path>,
exchange: &str,
symbol: &str,
bounds: ParquetScanBounds,
) -> Result<Self>
pub fn describe( root: impl AsRef<Path>, exchange: &str, symbol: &str, bounds: ParquetScanBounds, ) -> Result<Self>
Describe tick partitions and bind each path to its current file fingerprint.
Sourcepub fn describe_cancellable<F>(
root: impl AsRef<Path>,
exchange: &str,
symbol: &str,
bounds: ParquetScanBounds,
is_cancelled: F,
) -> Result<Self>
pub fn describe_cancellable<F>( root: impl AsRef<Path>, exchange: &str, symbol: &str, bounds: ParquetScanBounds, is_cancelled: F, ) -> Result<Self>
Describe tick partitions with cooperative cancellation.
Sourcepub fn cursor(&self) -> Result<ParquetTickCursor>
pub fn cursor(&self) -> Result<ParquetTickCursor>
Open a cursor against the file generations bound by this description.
Sourcepub fn cursor_with_read_size(
&self,
rows_per_read: usize,
) -> Result<ParquetTickCursor>
pub fn cursor_with_read_size( &self, rows_per_read: usize, ) -> Result<ParquetTickCursor>
Open a cursor with a maximum number of rows decoded per read.
Sourcepub fn latest_valid_tick_cancellable<F>(
&self,
is_cancelled: F,
) -> Result<Option<ParquetScannedRow<Tick>>>
pub fn latest_valid_tick_cancellable<F>( &self, is_cancelled: F, ) -> Result<Option<ParquetScannedRow<Tick>>>
Find the latest valid quote inside the inclusive scan bounds.
Sourcepub fn latest_valid_tick_before_cancellable<F>(
&self,
before: NaiveDateTime,
is_cancelled: F,
) -> Result<Option<ParquetScannedRow<Tick>>>
pub fn latest_valid_tick_before_cancellable<F>( &self, before: NaiveDateTime, is_cancelled: F, ) -> Result<Option<ParquetScannedRow<Tick>>>
Find the latest valid quote strictly before before and inside the scan bounds.