Bidirectional conversion between Polars DataFrames and domain types (Tick, Bar).
Functions
- bars_
to_ dataframe - Convert a slice of Bars into a Polars DataFrame.
- dataframe_
to_ bars - Convert a Polars DataFrame back into Vec
. - dataframe_
to_ ticks - Convert a Polars DataFrame back into Vec
. - ndt_
to_ date_ string - Extract the date portion from a NaiveDateTime as a formatted string.
- ticks_
to_ dataframe - Convert a slice of Ticks into a Polars DataFrame.