Module scanner

Module scanner 

Streaming cursors for ascending Parquet tick and bar partitions.

Structs

ParquetBarCursor
Partition-at-a-time cursor over ascending bar rows.
ParquetBarScan
An immutable description of bounded bar partitions.
ParquetScanBounds
Inclusive timestamp bounds for a Parquet cursor.
ParquetScannedRow
A decoded row paired with its physical ordinal in the described scan.
ParquetTickCursor
Partition-at-a-time cursor over ascending tick rows.
ParquetTickScan
An immutable description of bounded tick partitions.

Constants

DEFAULT_PARQUET_SCAN_ROWS
Default maximum number of rows decoded by one cursor read.