pub struct ParquetTickCursor { /* private fields */ }Expand description
Partition-at-a-time cursor over ascending tick rows.
Implementations
Sourceimpl ParquetTickCursor
impl ParquetTickCursor
Sourcepub fn open(
root: impl AsRef<Path>,
exchange: &str,
symbol: &str,
bounds: ParquetScanBounds,
) -> Result<Self>
pub fn open( root: impl AsRef<Path>, exchange: &str, symbol: &str, bounds: ParquetScanBounds, ) -> Result<Self>
Open a tick cursor directly from a Parquet data root.
Sourcepub fn open_with_read_size(
root: impl AsRef<Path>,
exchange: &str,
symbol: &str,
bounds: ParquetScanBounds,
rows_per_read: usize,
) -> Result<Self>
pub fn open_with_read_size( root: impl AsRef<Path>, exchange: &str, symbol: &str, bounds: ParquetScanBounds, rows_per_read: usize, ) -> Result<Self>
Open a tick cursor with a maximum number of rows decoded per read.
Sourcepub fn open_cancellable<F>(
root: impl AsRef<Path>,
exchange: &str,
symbol: &str,
bounds: ParquetScanBounds,
is_cancelled: F,
) -> Result<Self>
pub fn open_cancellable<F>( root: impl AsRef<Path>, exchange: &str, symbol: &str, bounds: ParquetScanBounds, is_cancelled: F, ) -> Result<Self>
Open a tick cursor while checking cancellation during partition discovery.
Sourcepub fn open_cancellable_with_read_size<F>(
root: impl AsRef<Path>,
exchange: &str,
symbol: &str,
bounds: ParquetScanBounds,
rows_per_read: usize,
is_cancelled: F,
) -> Result<Self>
pub fn open_cancellable_with_read_size<F>( root: impl AsRef<Path>, exchange: &str, symbol: &str, bounds: ParquetScanBounds, rows_per_read: usize, is_cancelled: F, ) -> Result<Self>
Open a bounded tick cursor with cancellable partition discovery.
Sourcepub fn next_tick_with_ordinal(
&mut self,
) -> Result<Option<ParquetScannedRow<Tick>>>
pub fn next_tick_with_ordinal( &mut self, ) -> Result<Option<ParquetScannedRow<Tick>>>
Read the next ascending tick with its physical source-row ordinal.
Sourcepub fn next_tick_cancellable<F>(
&mut self,
is_cancelled: F,
) -> Result<Option<Tick>>
pub fn next_tick_cancellable<F>( &mut self, is_cancelled: F, ) -> Result<Option<Tick>>
Read the next ascending tick with cooperative cancellation.
Sourcepub fn next_tick_with_ordinal_cancellable<F>(
&mut self,
is_cancelled: F,
) -> Result<Option<ParquetScannedRow<Tick>>>
pub fn next_tick_with_ordinal_cancellable<F>( &mut self, is_cancelled: F, ) -> Result<Option<ParquetScannedRow<Tick>>>
Read the next tick and source ordinal with cooperative cancellation.
Sourcepub fn remaining_partitions(&self) -> usize
pub fn remaining_partitions(&self) -> usize
Number of date partitions still active or pending.
Sourcepub fn rows_per_read(&self) -> usize
pub fn rows_per_read(&self) -> usize
Maximum number of rows decoded by one Parquet read.